@@ -1,3 +1,20 @@
+# Copyright 2009-2013 Justin Riley
+#
+# This file is part of StarCluster.
+#
+# StarCluster is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 3 of the License, or (at your option) any
+# later version.
+#
+# StarCluster is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with StarCluster. If not, see <http://www.gnu.org/licenses/>.
+
 import os
 
 from starcluster import exception
@@ -46,8 +63,8 @@ class CmdPut(ClusterCompleter):
             if not os.path.exists(lpath):
                 raise exception.BaseException(
                     "Local file or directory does not exist: %s" % lpath)
-        cl = self.cm.get_cluster(ctag)
-        node = cl.get_node_by_alias(self.opts.node)
+        cl = self.cm.get_cluster(ctag, load_receipt=False)
+        node = cl.get_node(self.opts.node)
         if self.opts.user:
             node.ssh.switch_user(self.opts.user)
         if len(lpaths) > 1 and not node.ssh.isdir(rpath):
