@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with StarCluster. If not, see <http://www.gnu.org/licenses/>.
 
-from datetime import datetime, timedelta
+from datetime import timedelta
 
 from starcluster import utils
 from starcluster import static
@@ -35,35 +35,38 @@ class CmdSpotHistory(CmdBase):
 
         $ starcluster spothistory m1.small
 
-    Do the same but also plot the spot history over time using matplotlib:
+    Do the same but also plot the spot history over time in a web browser:
 
         $ starcluster spothistory -p m1.small
     """
     names = ['spothistory', 'shi']
 
     def addopts(self, parser):
-        now_tup = datetime.now()
-        now = utils.datetime_tuple_to_iso(now_tup)
-        delta = now_tup - timedelta(days=30)
-        thirty_days_ago = utils.datetime_tuple_to_iso(delta)
         parser.add_option("-z", "--zone", dest="zone", default=None,
                           help="limit results to specific availability zone")
         parser.add_option("-d", "--days", dest="days_ago",
-                          action="store", type="float",
+                          action="store", type="float", default=None,
                           help="provide history in the last DAYS_AGO days "
-                          "(overrides -s and -e options)")
+                          "(overrides -s option)")
         parser.add_option("-s", "--start-time", dest="start_time",
-                          action="store", type="string",
-                          default=thirty_days_ago,
-                          help="show price history after START_TIME "
-                          "(e.g. 2010-01-15T22:22:22)")
+                          action="callback", type="string", default=None,
+                          callback=self._iso_timestamp,
+                          help="show price history after START_TIME (UTC)"
+                          "(e.g. 2010-01-15T22:22:22Z)")
         parser.add_option("-e", "--end-time", dest="end_time",
-                          action="store", type="string", default=now,
-                          help="show price history up until END_TIME "
-                          "(e.g. 2010-02-15T22:22:22)")
+                          action="callback", type="string", default=None,
+                          callback=self._iso_timestamp,
+                          help="show price history up until END_TIME (UTC)"
+                          "(e.g. 2010-02-15T22:22:22Z)")
         parser.add_option("-p", "--plot", dest="plot",
                           action="store_true", default=False,
-                          help="plot spot history using matplotlib")
+                          help="plot spot history in a web browser")
+        parser.add_option("-v", "--vpc", dest="vpc",
+                          action="store_true", default=False,
+                          help="show spot prices for VPC")
+        parser.add_option("-c", "--classic", dest="classic",
+                          action="store_true", default=False,
+                          help="show spot prices for EC2-Classic")
 
     def execute(self, args):
         instance_types = ', '.join(sorted(static.INSTANCE_TYPES.keys()))
@@ -71,6 +74,9 @@ class CmdSpotHistory(CmdBase):
             self.parser.error(
                 'please provide an instance type (options: %s)' %
                 instance_types)
+        if self.opts.classic and self.opts.vpc:
+            self.parser.error("options -c and -v cannot be specified at "
+                              "the same time")
         instance_type = args[0]
         if not instance_type in static.INSTANCE_TYPES:
             self.parser.error('invalid instance type. possible options: %s' %
@@ -78,11 +84,18 @@ class CmdSpotHistory(CmdBase):
         start = self.opts.start_time
         end = self.opts.end_time
         if self.opts.days_ago:
-            now = datetime.now()
-            end = utils.datetime_tuple_to_iso(now)
+            if self.opts.start_time:
+                self.parser.error("options -d and -s cannot be specified at "
+                                  "the same time")
+            if self.opts.end_time:
+                end_tup = utils.iso_to_datetime_tuple(self.opts.end_time)
+            else:
+                end_tup = utils.get_utc_now()
             start = utils.datetime_tuple_to_iso(
-                now - timedelta(days=self.opts.days_ago))
+                end_tup - timedelta(days=self.opts.days_ago))
         browser_cmd = self.cfg.globals.get("web_browser")
         self.ec2.get_spot_history(instance_type, start, end,
                                   zone=self.opts.zone, plot=self.opts.plot,
-                                  plot_web_browser=browser_cmd)
+                                  plot_web_browser=browser_cmd,
+                                  vpc=self.opts.vpc,
+                                  classic=self.opts.classic)
