@@ -136,7 +136,7 @@ class Node(object):
         if not self._alias:
             alias = self.tags.get('alias')
             if not alias:
-                aliasestxt = self.user_data.get(static.UD_ALIASES_FNAME)
+                aliasestxt = self.user_data.get(static.UD_ALIASES_FNAME, '')
                 aliases = aliasestxt.splitlines()[2:]
                 index = self.ami_launch_index
                 try:
@@ -327,6 +327,14 @@ class Node(object):
     def region(self):
         return self.instance.region
 
+    @property
+    def vpc_id(self):
+        return self.instance.vpc_id
+
+    @property
+    def subnet_id(self):
+        return self.instance.subnet_id
+
     @property
     def root_device_name(self):
         root_dev = self.instance.root_device_name
@@ -501,8 +509,8 @@ class Node(object):
             log.debug("Using existing key: %s" % private_key)
             key = self.ssh.load_remote_rsa_key(private_key)
         else:
-            key = self.ssh.generate_rsa_key()
-        pubkey_contents = self.ssh.get_public_key(key)
+            key = sshutils.generate_rsa_key()
+        pubkey_contents = sshutils.get_public_key(key)
         if not key_exists or ignore_existing:
             # copy public key to remote machine
             pub_key = self.ssh.remote_file(public_key, 'w')
@@ -533,7 +541,7 @@ class Node(object):
             # add public key used to create the connection to user's
             # authorized_keys
             conn_key = self.ssh._pkey
-            conn_pubkey_contents = self.ssh.get_public_key(conn_key)
+            conn_pubkey_contents = sshutils.get_public_key(conn_key)
             if conn_pubkey_contents not in auth_keys_contents:
                 log.debug("adding conn_pubkey_contents")
                 auth_keys.write('%s\n' % conn_pubkey_contents)
@@ -656,7 +664,8 @@ class Node(object):
         $ node.export_fs_to_nodes(nodes=[node1,node2],
                                   export_paths=['/home', '/opt/sge6'])
         """
-        # setup /etc/exports
+        log.debug("Cleaning up potentially stale NFS entries")
+        self.stop_exporting_fs_to_nodes(nodes, paths=export_paths)
         log.info("Configuring NFS exports path(s):\n%s" %
                  ' '.join(export_paths))
         nfs_export_settings = "(async,no_root_squash,no_subtree_check,rw)"
@@ -673,7 +682,7 @@ class Node(object):
         etc_exports.close()
         self.ssh.execute('exportfs -fra')
 
-    def stop_exporting_fs_to_nodes(self, nodes):
+    def stop_exporting_fs_to_nodes(self, nodes, paths=None):
         """
         Removes nodes from this node's /etc/exportfs
 
@@ -682,17 +691,34 @@ class Node(object):
         Example:
         $ node.remove_export_fs_to_nodes(nodes=[node1,node2])
         """
-        regex = '|'.join(map(lambda x: x.alias, nodes))
+        if paths:
+            regex = '|'.join([' '.join([path, node.alias]) for path in paths
+                              for node in nodes])
+        else:
+            regex = '|'.join([n.alias for n in nodes])
         self.ssh.remove_lines_from_file('/etc/exports', regex)
         self.ssh.execute('exportfs -fra')
 
     def start_nfs_server(self):
         log.info("Starting NFS server on %s" % self.alias)
-        self.ssh.execute('/etc/init.d/portmap start')
+        self.ssh.execute('/etc/init.d/portmap start', ignore_exit_status=True)
         self.ssh.execute('mount -t rpc_pipefs sunrpc /var/lib/nfs/rpc_pipefs/',
                          ignore_exit_status=True)
+        EXPORTSD = '/etc/exports.d'
+        DUMMY_EXPORT_DIR = '/dummy_export_for_broken_init_script'
+        DUMMY_EXPORT_LINE = ' '.join([DUMMY_EXPORT_DIR,
+                                      '127.0.0.1(ro,no_subtree_check)'])
+        DUMMY_EXPORT_FILE = posixpath.join(EXPORTSD, 'dummy.exports')
+        # Hack to get around broken debian nfs-kernel-server script
+        # http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=679274
+        self.ssh.execute("mkdir -p %s" % EXPORTSD)
+        self.ssh.execute("mkdir -p %s" % DUMMY_EXPORT_DIR)
+        with self.ssh.remote_file(DUMMY_EXPORT_FILE, 'w') as dummyf:
+            dummyf.write(DUMMY_EXPORT_LINE)
         self.ssh.execute('/etc/init.d/nfs start')
-        self.ssh.execute('/usr/sbin/exportfs -fra')
+        self.ssh.execute('rm -f %s' % DUMMY_EXPORT_FILE)
+        self.ssh.execute('rm -rf %s' % DUMMY_EXPORT_DIR)
+        self.ssh.execute('exportfs -fra')
 
     def mount_nfs_shares(self, server_node, remote_paths):
         """
@@ -721,9 +747,10 @@ class Node(object):
                                           remote_paths))
         self.ssh.remove_lines_from_file('/etc/fstab', remote_paths_regex)
         fstab = self.ssh.remote_file('/etc/fstab', 'a')
+        mount_opts = 'rw,exec,noauto'
         for path in remote_paths:
-            fstab.write('%s:%s %s nfs vers=3,user,rw,exec,noauto 0 0\n' %
-                        (server_node.alias, path, path))
+            fstab.write('%s:%s %s nfs %s 0 0\n' %
+                        (server_node.alias, path, path, mount_opts))
         fstab.close()
         for path in remote_paths:
             if not self.ssh.path_exists(path):
@@ -815,7 +842,16 @@ class Node(object):
         hostname_file = self.ssh.remote_file("/etc/hostname", "w")
         hostname_file.write(hostname)
         hostname_file.close()
-        self.ssh.execute('hostname -F /etc/hostname')
+        try:
+            self.ssh.execute('hostname -F /etc/hostname')
+        except:
+            if not utils.is_valid_hostname(hostname):
+                raise exception.InvalidHostname(
+                    "Please terminate and recreate this cluster with a name"
+                    " that is also a valid hostname.  This hostname is"
+                    " invalid: %s" % hostname)
+            else:
+                raise
 
     @property
     def network_names(self):
@@ -881,7 +917,7 @@ class Node(object):
             return spot[0]
 
     def is_master(self):
-        return self.alias == "master"
+        return self.alias == 'master' or self.alias.endswith("-master")
 
     def is_instance_store(self):
         return self.instance.root_device_type == "instance-store"
@@ -896,7 +932,7 @@ class Node(object):
         return self.instance.instance_type in static.CLUSTER_GPU_TYPES
 
     def is_cluster_type(self):
-        return self.instance.instance_type in static.CLUSTER_TYPES
+        return self.instance.instance_type in static.HVM_ONLY_TYPES
 
     def is_spot(self):
         return self.spot_id is not None
@@ -1005,16 +1041,32 @@ class Node(object):
         self.instance = res[0]
         return self.state
 
+    @property
+    def addr(self):
+        """
+        Returns the most widely accessible address for the instance. This
+        property first checks if dns_name is available, then the public ip, and
+        finally the private ip. If none of these addresses are available it
+        returns None.
+        """
+        if not self.dns_name:
+            if self.ip_address:
+                return self.ip_address
+            else:
+                return self.private_ip_address
+        else:
+            return self.dns_name
+
     @property
     def ssh(self):
         if not self._ssh:
-            self._ssh = sshutils.SSHClient(self.instance.dns_name,
+            self._ssh = sshutils.SSHClient(self.addr,
                                            username=self.user,
                                            private_key=self.key_location)
         return self._ssh
 
     def shell(self, user=None, forward_x11=False, forward_agent=False,
-              command=None):
+              pseudo_tty=False, command=None):
         """
         Attempts to launch an interactive shell by first trying the system's
         ssh client. If the system does not have the ssh command it falls back
@@ -1042,8 +1094,10 @@ class Node(object):
                 sshopts += ' -Y'
             if forward_agent:
                 sshopts += ' -A'
+            if pseudo_tty:
+                sshopts += ' -t'
             ssh_cmd = static.SSH_TEMPLATE % dict(opts=sshopts, user=user,
-                                                 host=self.dns_name)
+                                                 host=self.addr)
             if command:
                 command = "'source /etc/profile && %s'" % command
                 ssh_cmd = ' '.join([ssh_cmd, command])
@@ -1056,6 +1110,9 @@ class Node(object):
             if forward_agent:
                 log.warn("Authentication agent forwarding not available in " +
                          "Python SSH client")
+            if pseudo_tty:
+                log.warn("Pseudo-tty allocation is not available in " +
+                         "Python SSH client")
             if command:
                 orig_user = self.ssh.get_current_user()
                 self.ssh.switch_user(user)
@@ -1087,6 +1144,7 @@ class Node(object):
         pkgs is a string that contains one or more packages separated by a
         space
         """
+        self.apt_command('update')
         self.apt_command('install %s' % pkgs)
 
     def yum_command(self, cmd):
@@ -1114,7 +1172,7 @@ class Node(object):
         /usr/bin/apt exists on the node, and use apt if it exists. Otherwise
         test to see if /usr/bin/yum exists and use that.
         """
-        if self.ssh.isfile('/usr/bin/apt'):
+        if self.ssh.isfile('/usr/bin/apt-get'):
             return "apt"
         elif self.ssh.isfile('/usr/bin/yum'):
             return "yum"
